@@ -1,10 +1,20 @@
+from openpyxl import Workbook
 from openpyxl.styles import Font, colors, Alignment, Border, Side
 
 from mark_excel.write import Write
 
 
 class MarkExcel(object):
-    def __init__(self, height=30, width=20, font=None, align=None, border=None):
+    def __init__(self, height=30, width=20, font=None, align=None, border=None, need_default_sheet=True):
+        """
+        实例化
+        :param height: 单元格高度
+        :param width: 单元格宽带
+        :param font: 字体
+        :param align: 对齐方式
+        :param border: 边框
+        :param need_default_sheet: 是否需要默认的sheet
+        """
         # height：单元格的高度
         self.height = height
         # width：单元格的宽度
@@ -21,4 +31,11 @@ class MarkExcel(object):
 
         self.LINE = ["A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S",
                      "T", "U", "V", "W", "X", "Y", "Z"]
+        # excel对象
+        self.workbook = Workbook()
+        # 是否需要默认的sheet
+        if not need_default_sheet:
+            # 不需要就删除
+            self.workbook.remove(self.workbook.worksheets[0])
+        # 写入对象
         self.write = Write(self)
